@@ -13,8 +13,8 @@ int main(int argc, char *argv[])
 
     SwipeCounter s;
     QMaemo5HomescreenAdaptor *adaptor = new QMaemo5HomescreenAdaptor(&s);
-//    adaptor->setSettingsAvailable(true);
-//    QObject::connect(adaptor, SIGNAL(settingsRequested()), &s,SLOT(showSettingsDialog()));
+    adaptor->setSettingsAvailable(true);
+    QObject::connect(adaptor, SIGNAL(settingsRequested()), &s,SLOT(showSettingsDialog()));
     s.show();
     app.exec();
 }
