@@ -1,8 +1,8 @@
 #include "swipecounter.h"
 #include <QDebug>
-
+#include <QPushButton>
 SwipeCounter::SwipeCounter(){
-   
+
     this->setFixedSize(200,100);
     swipes = set.value("swipes",0).toInt();
     dist = swipes*7.6;
@@ -24,8 +24,22 @@ SwipeCounter::SwipeCounter(){
     lay->setAlignment(Qt::AlignCenter);
     setLayout(lay);
     setAttribute(Qt::WA_TranslucentBackground);
-   }
+}
 void SwipeCounter::showSettingsDialog(){
+
+    QDialog *dialog = new QDialog();
+    dialog->setWindowTitle("SwipeCounter");
+    QLabel *label = new QLabel(dialog);
+    label->setText("SwipeCounter v0.2  Sampo Savola 2010" );
+    reset = new QPushButton(dialog);
+    reset->setText("Reset Counter");
+    connect(reset,SIGNAL(clicked()),this,SLOT(resetCounter()));
+
+    QVBoxLayout *lay = new QVBoxLayout(dialog);
+    lay->addWidget(label);
+    lay->addWidget(reset);
+    lay->setAlignment(Qt::AlignCenter);
+    dialog->show();
 }
 
 void SwipeCounter::desktopChanged(){
@@ -41,3 +55,11 @@ void SwipeCounter::desktopChanged(){
     }
     set.setValue("swipes",swipes);
 }
+void SwipeCounter::resetCounter(){
+
+    set.setValue("swipes",0);
+    swipes = 0;
+    count->setText("Swipes: 0");
+    distance->setText("0 cm");
+    reset->setDisabled(true);
+}
