@@ -20,6 +20,7 @@ public:
 public slots:
     void showSettingsDialog();
     void desktopChanged();
+    void resetCounter();
 private:
     QLabel *count;
     QLabel *distance;
@@ -27,6 +28,7 @@ private:
     int swipes;
     double dist;
     QSettings set;
+    QPushButton *reset;
 
 };
 
